let CaseSensitivePathsPlugin = require('case-sensitive-paths-webpack-plugin');
let ExtractTextPlugin = require('extract-text-webpack-plugin');
let path = require('path');
let fs = require('fs');
let webpack = require('webpack');
let baseWebpackConfig = require('./shared/baseWebpackConfig');
let config = require('../../scripts/util/config');
let {rules} = require('./shared/rules');



let manifest;

if (fs.existsSync(`${process.cwd()}/src/.dll/common-manifest.json`)) {
  manifest = require(`${process.cwd()}/src/.dll/common-manifest.json`);
}  else {
  manifest = {}
}


let webpackConfiguration = Object.assign({}, baseWebpackConfig, {
  entry: ['babel-polyfill',
    `webpack-dev-server/client?http://127.0.0.1:${config.port}`,
    'webpack/hot/only-dev-server',
    `${process.cwd()}/src/develop`
  ],
  cache: true,
  output: {
    filename: 'index.js'
  },
  devServer: {
    contentBase: './src/',
    historyApiFallback: true,
    hot: true,
    port: config.port,
    publicPath: config.webpackPublicPath,
    noInfo: false
  },

  devtool: 'inline-source-map',
  plugins: [
    new CaseSensitivePathsPlugin(),
    new webpack.DllReferencePlugin({
      context: path.join(process.cwd(), '/src'),
      manifest
    }),
    new webpack.HotModuleReplacementPlugin(),
    new webpack.NoEmitOnErrorsPlugin(),
    new ExtractTextPlugin({
      filename: 'bundle.css',
      disable: false,
      allChunks: true
    }),
    new webpack.DefinePlugin({
      'process.env': config.envVariables
    })
  ],
  module: {
    rules
  }
});

// Add needed loaders to the defaults here
webpackConfiguration.module.rules.push({
  test: /\.(js|jsx)$/,
  include: require('./shared/include'),
  use: {
    loader: 'babel-loader',
    options: {
      presets: ['react', 'es2015']
    }
  }
});

webpackConfiguration.module.rules.push({
  test: /\.jsx?$/, // both .js and .jsx
  loader: 'eslint-loader',
  include: path.resolve(process.cwd(), 'src'),
  enforce: 'pre',
  options: {
    configFile: '.eslintrc'
  }
});

module.exports = webpackConfiguration;