let ExtractTextPlugin = require('extract-text-webpack-plugin');
let path = require('path');
let webpack = require('webpack');
let baseWebpackConfig = require('./shared/baseWebpackConfig');
let envConfig = require('../../scripts/util/config');
let {rules} = require('./shared/rules');

let config = Object.assign({}, baseWebpackConfig, {
  entry: {
    common: [`${process.cwd()}/src/.dll/common.dll.js`]
  },
  cache: true,
  devServer: {
    contentBase: './src/',
    historyApiFallback: true,
    hot: true,
    port: envConfig.port,
    publicPath: envConfig.publicPath,
    noInfo: false
  },
  output: {
    filename: '[name].js',
    path: `${process.cwd()}/src/.dll/`,
    // The name of the global variable which the library's
    // require() function will be assigned to
    library: '[name]'
  },
  plugins: [
    new webpack.DllPlugin({
      path: path.join(process.cwd(), '/src/.dll/', '[name]-manifest.json'),
      name: '[name]',
      context: path.resolve(process.cwd(), 'src')
    }),
    new webpack.HotModuleReplacementPlugin(),
    new webpack.NoEmitOnErrorsPlugin(),
    new ExtractTextPlugin({
      filename : 'bundle.css',
      disable : false,
      allChunks : true
    })
  ],
  module: {
    rules
  }
});

// Add needed loaders to the defaults here
config.module.rules.push({
  test: /\.(js|jsx)$/,
  include: require('./shared/include'),
  use : {
    loader : 'babel-loader',
    options : {
      presets : ['react', 'es2015']
    }
  }
});

config.module.rules.push({
  test: /\.jsx?$/, // both .js and .jsx
  loader: 'eslint-loader',
  include: path.resolve(process.cwd(), 'src'),
  enforce: 'pre',
  options: {
    configFile : '.eslintrc'
  }
});

module.exports = config;