let baseWebpackConfig = require('./shared/baseWebpackConfig');
let config = require('../../scripts/util/config');
let fileName = '[name].js';
let CaseSensitivePathsPlugin = require('case-sensitive-paths-webpack-plugin');
let ExtractTextPlugin = require('extract-text-webpack-plugin');
let path = require('path');
let webpack = require('webpack');
let {rules} = require('./shared/rules');
let entryFiles = {
  index: `${process.cwd()}/src/index`
};

let webpackConfiguration = Object.assign({}, baseWebpackConfig, {
  entry: entryFiles,
  cache: false,
  output: {
    path: `${process.cwd()}/dist`,
    filename: fileName,
    publicPath: config.webpackPublicPath,
    libraryTarget: 'umd',
    sourceMapFilename: '[file].map'
  },
  plugins: [
    new CaseSensitivePathsPlugin(),
    new webpack.optimize.AggressiveMergingPlugin(),
    new ExtractTextPlugin({
      filename: 'bundle.css',
      disable: false,
      allChunks: true
    }),
    // Set the process.env to production so React includes the production
    // version of itself
    new webpack.DefinePlugin({
      'process.env': config.envVariables
    })
  ],
  module: {
    rules
  }
});

// Add needed loaders to the defaults here
webpackConfiguration.module.rules.push({
  test: /\.(js|jsx)$/,
  include: require('./shared/include'),
  use: {
    loader: 'babel-loader',
    options: {
      presets: ['react', 'es2015']
    }
  }
});

webpackConfiguration.module.rules.push({
  test: /\.jsx?$/, // both .js and .jsx
  loader: 'eslint-loader',
  include: path.resolve(process.cwd(), 'src'),
  enforce: 'pre',
  options: {
    configFile: '.eslintrc'
  }
});



if (config.envVariables.isMinified == 1) {
  webpackConfiguration.plugins.push(
    new webpack.optimize.UglifyJsPlugin({
      sourceMap: true
    })
  );
}

module.exports = webpackConfiguration;